==================
mog-commons-python
==================

Common utility library for Python

.. image:: https://badge.fury.io/py/mog-commons.svg
   :target: http://badge.fury.io/py/mog-commons
   :alt: PyPI version

.. image:: https://travis-ci.org/mogproject/mog-commons-python.svg?branch=master
   :target: https://travis-ci.org/mogproject/mog-commons-python
   :alt: Build Status

.. image:: https://coveralls.io/repos/mogproject/mog-commons-python/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/mogproject/mog-commons-python?branch=master
   :alt: Coverage Status

.. image:: https://img.shields.io/badge/license-Apache%202.0-blue.svg
   :target: http://choosealicense.com/licenses/apache-2.0/
   :alt: License

.. image:: https://badge.waffle.io/mogproject/mog-commons-python.svg?label=ready&title=Ready
   :target: https://waffle.io/mogproject/mog-commons-python
   :alt: 'Stories in Ready'

------------
Dependencies
------------

* Python: 2.6 / 2.7 / 3.2 / 3.3 / 3.4 / 3.5
* six
* unittest2
* jinja2: 2.6

------------
Installation
------------

* ``pip`` command may need ``sudo``

+-------------------------+---------------------------------------+
| Operation               | Command                               |
+=========================+=======================================+
| Install                 |``pip install mog-commons``            |
+-------------------------+---------------------------------------+
| Upgrade                 |``pip install --upgrade mog-commons``  |
+-------------------------+---------------------------------------+
| Uninstall               |``pip uninstall mog-commons``          |
+-------------------------+---------------------------------------+
